@@ -1,4 +1,4 @@
-__version__ = '0.1.18'
+__version__ = '0.1.19'
 
 DB_VERSION = 1
 
@@ -1030,6 +1030,30 @@ class YEDB():
             k.data.update(data)
             k.set_modified()
 
+    def key_increment(self, key):
+        with self.lock:
+            try:
+                value = self._get(key)[0]
+            except KeyError:
+                value = 0
+            if not isinstance(value, int):
+                raise ValueError(f'Unable to increment {key}')
+            value += 1
+            self.key_set(key, value)
+            return value
+
+    def key_decrement(self, key):
+        with self.lock:
+            try:
+                value = self._get(key)[0]
+            except KeyError:
+                value = 0
+            if not isinstance(value, int):
+                raise ValueError(f'Unable to increment {key}')
+            value -= 1
+            self.key_set(key, value)
+            return value
+
     def key_as_dict(self, key):
         """
         Returns KeyDict object
