@@ -105,7 +105,20 @@ def cli():
         if v is None:
             tp = '<null>'
         else:
-            tp = v.__class__.__name__
+            if isinstance(v, bool):
+                tp = 'boolean'
+            elif isinstance(v, float) or isinstance(v, int):
+                tp = 'number'
+            elif isinstance(v, str):
+                tp = 'string'
+            elif isinstance(v, list) or isinstance(v, tuple):
+                tp = 'array'
+            elif isinstance(v, dict):
+                tp = 'object'
+            elif isinstance(v, bytes):
+                tp = 'bytes'
+            else:
+                tp = f'class:{result[0].__class__.__name__}'
         return tp
 
     def convert_value_from(value, p):
@@ -322,6 +335,10 @@ def cli():
             elif cmd == 'server':
                 db.server_set(name=kwargs.get('_option'),
                               value=yedb.val_to_boolean(kwargs.get('VALUE')))
+            elif cmd == 'incr':
+                print(db.key_increment(key=kwargs.get('KEY')))
+            elif cmd == 'decr':
+                print(db.key_decrement(key=kwargs.get('KEY')))
             elif cmd == 'dump':
                 func = kwargs.get('_func')
                 if func is None:
@@ -656,8 +673,8 @@ def cli():
                 tasks = []
                 test_arr = [777.777] * 100
                 test_dict = {f'v{n}': n * 777.777 for n in range(100)}
-                for n, v in [('numeric', 777.777), ('string', 'x' * 1000),
-                             ('array', test_arr), ('dict', test_dict)]:
+                for n, v in [('number', 777.777), ('string', 'x' * 1000),
+                             ('array', test_arr), ('object', test_dict)]:
                     start = time.perf_counter()
 
                     for i in range(threads):
@@ -677,8 +694,8 @@ def cli():
                 print()
                 list(db.purge())
                 for c in range(2):
-                    for n, v in [('numeric', 777.777), ('string', 'x' * 1000),
-                                 ('array', test_arr), ('dict', test_dict)]:
+                    for n, v in [('number', 777.777), ('string', 'x' * 1000),
+                                 ('array', test_arr), ('object', test_dict)]:
                         start = time.perf_counter()
                         for z in range(threads):
                             tasks.append(
@@ -725,6 +742,12 @@ def cli():
     ap_get.add_argument('KEY', help='Key name or <key>:<field> for dict keys'
                        ).completer = KeyCompleter()
 
+    ap_get = sp.add_parser('incr', help='Increment numeric key')
+    ap_get.add_argument('KEY', help='Key name').completer = KeyCompleter()
+
+    ap_get = sp.add_parser('decr', help='Decrement numeric key')
+    ap_get.add_argument('KEY', help='Key name').completer = KeyCompleter()
+
     ap_explain = sp.add_parser('explain', help='Get key extended info')
     ap_explain.add_argument('KEY').completer = KeyCompleter()
 
